@@ -628,18 +628,6 @@ extern "C" {
 
 //@}
 
-/**
- * @name Some numbers useful in numerical algorithms - but not
- * affecting precision, otherwise would be in precision structure
- */
-
-//@{
-
-#define _tau_reio_BIG_ 0.2      /**< maximal \f$ tau_reio \f$ */
-#define _tau_reio_SMALL_ 0.004  /**< minimal \f$ tau_reio \f$ */
-
-//@}
-
 /**
  * @name Some basic constants needed by RECFAST:
  */
